@@ -67,9 +67,8 @@ QPixmap *AgendaItem::eventPxmp = nullptr;
 
 //-----------------------------------------------------------------------------
 
-AgendaItem::AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calendar,
-                       const KCalCore::Incidence::Ptr &item, int itemPos, int itemCount,
-                       const QDateTime &qd, bool isSelected, QWidget *parent)
+AgendaItem::AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calendar, const KCalCore::Incidence::Ptr &item, int itemPos, int itemCount, const QDateTime &qd, bool isSelected,
+                       QWidget *parent)
     : QWidget(parent)
     , mEventView(eventView)
     , mCalendar(calendar)
@@ -275,8 +274,7 @@ void AgendaItem::setCellY(int YTop, int YBottom)
     mCellYBottom = YBottom;
 }
 
-void AgendaItem::setMultiItem(const AgendaItem::QPtr &first, const AgendaItem::QPtr &prev,
-                              const AgendaItem::QPtr &next, const AgendaItem::QPtr &last)
+void AgendaItem::setMultiItem(const AgendaItem::QPtr &first, const AgendaItem::QPtr &prev, const AgendaItem::QPtr &next, const AgendaItem::QPtr &last)
 {
     if (!mMultiItemInfo) {
         mMultiItemInfo = new MultiItemInfo;
@@ -668,7 +666,7 @@ void AgendaItem::dropEvent(QDropEvent *e)
 
     bool decoded = md->hasText();
     QString text = md->text();
-    if (decoded && text.startsWith(QStringLiteral("file:"))) {
+    if (decoded && text.startsWith(QLatin1String("file:"))) {
         mIncidence->addAttachment(KCalCore::Attachment::Ptr(new KCalCore::Attachment(text)));
         return;
     }
@@ -725,8 +723,7 @@ bool AgendaItem::overlaps(CellItem *o) const
     return false;
 }
 
-static void conditionalPaint(QPainter *p, bool condition, int &x, int y, int ft,
-                             const QPixmap &pxmp)
+static void conditionalPaint(QPainter *p, bool condition, int &x, int y, int ft, const QPixmap &pxmp)
 {
     if (condition) {
         p->drawPixmap(x, y, pxmp);
@@ -846,84 +843,13 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
             = new QPixmap(QIcon::fromTheme(QStringLiteral("meeting-organizer")).pixmap(16, 16));
     }
 
-    QColor bgColor;
+    const auto categoryColor = getCategoryColor();
+    const auto resourceColor = mResourceColor.isValid() ? mResourceColor : categoryColor;
+    const auto frameColor = getFrameColor(resourceColor, categoryColor);
+    const auto bgBaseColor = getBackgroundColor(resourceColor, categoryColor);
+    const auto bgColor = mSelected ? bgBaseColor.lighter(EventView::BRIGHTNESS_FACTOR) : bgBaseColor;
+    const auto textColor = EventViews::getTextColor(bgColor);
 
-    if (CalendarSupport::hasTodo(mIncidence)
-        && !mEventView->preferences()->todosUseCategoryColors()) {
-        Todo::Ptr todo = CalendarSupport::todo(mIncidence);
-        Q_ASSERT(todo);
-        const QDate dueDate = todo->dtDue().toLocalTime().date();
-        const QDate today = QDate::currentDate();
-        const QDate occurrenceDate = this->occurrenceDate();
-        if (todo->isOverdue() && today >= occurrenceDate) {
-            bgColor = mEventView->preferences()->todoOverdueColor();
-        } else if (dueDate == today && dueDate == occurrenceDate) {
-            bgColor = mEventView->preferences()->todoDueTodayColor();
-        }
-    }
-
-    QColor categoryColor;
-    const QStringList categories = mIncidence->categories();
-    QString cat;
-    if (!categories.isEmpty()) {
-        cat = categories.first();
-    }
-
-    categoryColor = cat.isEmpty() ? CalendarSupport::KCalPrefs::instance()->unsetCategoryColor()
-                    : CalendarSupport::KCalPrefs::instance()->categoryColor(cat);
-
-    QColor resourceColor = mResourceColor;
-    if (!resourceColor.isValid()) {
-        resourceColor = categoryColor;
-    }
-
-    QColor frameColor;
-    // TODO PrefsBase enums should probably be redefined in Prefs
-    if (mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceOnly
-        || mEventView->preferences()->agendaViewColors()
-        == PrefsBase::CategoryInsideResourceOutside) {
-        frameColor = bgColor.isValid() ? bgColor : resourceColor;
-    } else {
-        frameColor = bgColor.isValid() ? bgColor : categoryColor;
-    }
-
-    if (!bgColor.isValid()) {
-        if (mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceOnly
-            || mEventView->preferences()->agendaViewColors()
-            == PrefsBase::ResourceInsideCategoryOutside) {
-            bgColor = resourceColor;
-        } else {
-            bgColor = categoryColor;
-        }
-    }
-
-    if (cat.isEmpty()
-        && mEventView->preferences()->agendaViewColors()
-        == PrefsBase::ResourceInsideCategoryOutside) {
-        frameColor = bgColor;
-    }
-
-    if (cat.isEmpty()
-        && mEventView->preferences()->agendaViewColors()
-        == PrefsBase::CategoryInsideResourceOutside) {
-        bgColor = frameColor;
-    }
-
-    frameColor = EventView::itemFrameColor(frameColor, mSelected);
-
-    if (!CalendarSupport::KCalPrefs::instance()->hasCategoryColor(cat)) {
-        categoryColor = resourceColor;
-    }
-
-    if (!bgColor.isValid()) {
-        bgColor = categoryColor;
-    }
-
-    if (mSelected) {
-        bgColor = bgColor.lighter(EventView::BRIGHTNESS_FACTOR);
-    }
-
-    const QColor textColor = EventViews::getTextColor(bgColor);
     p.setPen(textColor);
 
     p.setFont(mEventView->preferences()->agendaViewFont());
@@ -1133,9 +1059,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     }
 }
 
-void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect, bool selected,
-                                 const QColor &bgColor, bool frame, int ft, bool roundTop,
-                                 bool roundBottom)
+void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect, bool selected, const QColor &bgColor, bool frame, int ft, bool roundTop, bool roundBottom)
 {
     Q_UNUSED(ft);
     if (!mValid) {
@@ -1350,6 +1274,47 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect, bool selected,
     p->restore();
 }
 
+QColor AgendaItem::getCategoryColor() const
+{
+    const QStringList &categories = mIncidence->categories();
+    if (categories.isEmpty() || !CalendarSupport::KCalPrefs::instance()->hasCategoryColor(categories.first())) {
+        const auto colorPreference = mEventView->preferences()->agendaViewColors();
+        if (colorPreference == PrefsBase::CategoryOnly || !mResourceColor.isValid()) {
+            return CalendarSupport::KCalPrefs::instance()->unsetCategoryColor();
+        }
+        return mResourceColor;
+    }
+    return CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first());
+}
+
+QColor AgendaItem::getFrameColor(const QColor &resourceColor, const QColor &categoryColor) const
+{
+    const auto colorPreference = mEventView->preferences()->agendaViewColors();
+    const bool frameDisplaysCategory = (colorPreference == PrefsBase::CategoryOnly
+                                        || colorPreference == PrefsBase::ResourceInsideCategoryOutside);
+    return frameDisplaysCategory ? categoryColor : resourceColor;
+}
+
+QColor AgendaItem::getBackgroundColor(const QColor &resourceColor, const QColor &categoryColor) const
+{
+    if (CalendarSupport::hasTodo(mIncidence) && !mEventView->preferences()->todosUseCategoryColors()) {
+        Todo::Ptr todo = CalendarSupport::todo(mIncidence);
+        Q_ASSERT(todo);
+        const QDate dueDate = todo->dtDue().toLocalTime().date();
+        const QDate today = QDate::currentDate();
+        const QDate occurrenceDate = this->occurrenceDate();
+        if (todo->isOverdue() && today >= occurrenceDate) {
+            return mEventView->preferences()->todoOverdueColor();
+        } else if (dueDate == today && dueDate == occurrenceDate) {
+            return mEventView->preferences()->todoDueTodayColor();
+        }
+    }
+    const auto colorPreference = mEventView->preferences()->agendaViewColors();
+    const bool bgDisplaysCategory = (colorPreference == PrefsBase::CategoryOnly
+                                     || colorPreference == PrefsBase::CategoryInsideResourceOutside);
+    return bgDisplaysCategory ? categoryColor : resourceColor;
+}
+
 bool AgendaItem::eventFilter(QObject *obj, QEvent *event)
 {
     if (event->type() == QEvent::Paint) {
