@@ -45,7 +45,7 @@ class EVENTVIEWS_EXPORT MonthItem : public QObject
 
 public:
     explicit MonthItem(MonthScene *monthWidget);
-    virtual ~MonthItem();
+    ~MonthItem() override;
 
     QWidget *parentWidget() const;
 
@@ -71,18 +71,18 @@ public:
       The start date of the incidence, generally realStartDate. But it
       reflect changes, even during move.
     */
-    QDate startDate() const;
+    Q_REQUIRED_RESULT QDate startDate() const;
 
     /**
       The end date of the incidence, generally realEndDate. But it
       reflect changes, even during move.
      */
-    QDate endDate() const;
+    Q_REQUIRED_RESULT QDate endDate() const;
 
     /**
       The number of days this item spans.
     */
-    int daySpan() const;
+    Q_REQUIRED_RESULT int daySpan() const;
 
     /**
       This is the real start date, usually the start date of the incidence.
@@ -116,7 +116,7 @@ public:
     /**
       Returns true if this item is selected.
     */
-    bool selected() const
+    Q_REQUIRED_RESULT bool selected() const
     {
         return mSelected;
     }
@@ -124,7 +124,7 @@ public:
     /**
       Returns the position of the item ( > 0 ).
     */
-    int position() const
+    Q_REQUIRED_RESULT int position() const
     {
         return mPosition;
     }
@@ -172,7 +172,7 @@ public:
     /**
       Returns true if the item is being moved.
     */
-    bool isMoving() const
+    Q_REQUIRED_RESULT bool isMoving() const
     {
         return mMoving;
     }
@@ -180,7 +180,7 @@ public:
     /**
       Returns true if the item is being resized.
     */
-    bool isResizing() const
+    Q_REQUIRED_RESULT bool isResizing() const
     {
         return mResizing;
     }
@@ -237,12 +237,12 @@ public:
     /**
       Returns the background color of the item.
     */
-    virtual QColor bgColor() const = 0;
+    virtual Q_REQUIRED_RESULT QColor bgColor() const = 0;
 
     /**
       Returns the frame color of the item.
     */
-    virtual QColor frameColor() const = 0;
+    virtual Q_REQUIRED_RESULT QColor frameColor() const = 0;
 
     /**
       Returns a list of pixmaps to draw next to the items.
@@ -286,11 +286,9 @@ class EVENTVIEWS_EXPORT IncidenceMonthItem : public MonthItem
     Q_OBJECT
 
 public:
-    IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ETMCalendar::Ptr &calendar,
-                       const Akonadi::Item &item, const KCalCore::Incidence::Ptr &incidence,
-                       const QDate &recurStartDate = QDate());
+    IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &item, const KCalCore::Incidence::Ptr &incidence, const QDate &recurStartDate = QDate());
 
-    virtual ~IncidenceMonthItem();
+    ~IncidenceMonthItem() override;
 
     KCalCore::Incidence::Ptr incidence() const;
     Akonadi::Item akonadiItem() const;
@@ -348,7 +346,7 @@ class EVENTVIEWS_EXPORT HolidayMonthItem : public MonthItem
 
 public:
     HolidayMonthItem(MonthScene *monthScene, const QDate &date, const QString &name);
-    virtual ~HolidayMonthItem();
+    ~HolidayMonthItem() override;
 
     bool greaterThanFallback(const MonthItem *other) const override;
 
