@@ -27,11 +27,12 @@
 #include "prefs_base.h"
 
 #include "calendarview_debug.h"
-#include <QFontDatabase>
 
 #include <AkonadiCore/AttributeFactory>
 #include <AkonadiCore/CollectionColorAttribute>
 
+#include <QFontDatabase>
+
 using namespace EventViews;
 
 QSet<EventViews::EventView::ItemIcon> iconArrayToSet(const QByteArray &array)
@@ -163,18 +164,13 @@ void BaseConfig::usrSetDefaults()
 
 void BaseConfig::usrRead()
 {
-    // Note that the [Category Colors] group was removed after 3.2 due to
-    // an algorithm change. That's why we now use [Category Colors2]
-    // Resource colors
     KConfigGroup rColorsConfig(config(), "Resources Colors");
     const QStringList colorKeyList = rColorsConfig.keyList();
 
-    QStringList::ConstIterator it3;
-    QStringList::ConstIterator end3(colorKeyList.end());
-    for (it3 = colorKeyList.begin(); it3 != end3; ++it3) {
-        QColor color = rColorsConfig.readEntry(*it3, mDefaultResourceColor);
-        //qCDebug(CALENDARVIEW_LOG) << "key:" << (*it3) << "value:" << color;
-        setResourceColor(*it3, color);
+    for (const QString &key : colorKeyList) {
+        QColor color = rColorsConfig.readEntry(key, mDefaultResourceColor);
+        //qCDebug(CALENDARVIEW_LOG) << "key:" << key << "value:" << color;
+        setResourceColor(key, color);
     }
 
 #if 0
@@ -204,11 +200,8 @@ void BaseConfig::usrRead()
 bool BaseConfig::usrSave()
 {
     KConfigGroup rColorsConfig(config(), "Resources Colors");
-    QHash<QString, QColor>::const_iterator i = mResourceColors.constBegin();
-    QHash<QString, QColor>::const_iterator end(mResourceColors.constEnd());
-    while (i != end) {
-        rColorsConfig.writeEntry(i.key(), i.value());
-        ++i;
+    for (auto it = mResourceColors.constBegin(); it != mResourceColors.constEnd(); ++it) {
+        rColorsConfig.writeEntry(it.key(), it.value());
     }
 
 #if 0
@@ -238,7 +231,8 @@ bool BaseConfig::usrSave()
 class Q_DECL_HIDDEN Prefs::Private
 {
 public:
-    Private(Prefs *parent) : mAppConfig(nullptr)
+    Private(Prefs *parent)
+        : mAppConfig(nullptr)
         , q(parent)
     {
     }
@@ -263,8 +257,7 @@ public:
     void setDateTime(KCoreConfigSkeleton::ItemDateTime *baseConfigItem, const QDateTime &value);
     QDateTime getDateTime(const KCoreConfigSkeleton::ItemDateTime *baseConfigItem) const;
 
-    void setStringList(KCoreConfigSkeleton::ItemStringList *baseConfigItem,
-                       const QStringList &value);
+    void setStringList(KCoreConfigSkeleton::ItemStringList *baseConfigItem, const QStringList &value);
     QStringList getStringList(const KCoreConfigSkeleton::ItemStringList *baseConfigItem) const;
 
     void setColor(KConfigSkeleton::ItemColor *baseConfigItem, const QColor &value);
@@ -615,6 +608,16 @@ QDateTime Prefs::dayBegins() const
     return d->getDateTime(d->mBaseConfig.dayBeginsItem());
 }
 
+void Prefs::setFirstDayOfWeek(const int day)
+{
+    d->setInt(d->mBaseConfig.weekStartDayItem(), day - 1);
+}
+
+int Prefs::firstDayOfWeek() const
+{
+    return d->getInt(d->mBaseConfig.weekStartDayItem()) + 1;
+}
+
 void Prefs::setWorkingHoursStart(const QDateTime &dateTime)
 {
     d->setDateTime(d->mBaseConfig.workingHoursStartItem(), dateTime);
@@ -945,27 +948,10 @@ void Prefs::setResourceColor(const QString &cal, const QColor &color)
     d->mBaseConfig.setResourceColor(cal, color);
 }
 
-#define USE_RANDOM
-void Prefs::createNewColor(QColor &defColor, int seed)
-{
-#ifdef USE_RANDOM
-    Q_UNUSED(seed);
-    QColor col = QColor(qrand() % 256, qrand() % 256, qrand() % 256);
-    defColor = col;
-#else
-    int h, s, v;
-    defColor.getHsv(&h, &s, &v);
-    h = (seed % 12) * 30;
-    s -= s * static_cast<int>(((seed / 12) % 2) * 0.5);
-    defColor.setHsv(h, s, v);
-#endif
-}
-
 QColor Prefs::resourceColorKnown(const QString &cal) const
 {
     QColor color;
-    if (!cal.isEmpty()
-        && d->mBaseConfig.mResourceColors.contains(cal)) {
+    if (!cal.isEmpty()) {
         color = d->mBaseConfig.mResourceColors.value(cal);
     }
     return color;
@@ -980,19 +966,17 @@ QColor Prefs::resourceColor(const QString &cal)
     QColor color = resourceColorKnown(cal);
 
     // assign default color if enabled
-    if (!color.isValid()
-        && d->getBool(d->mBaseConfig.assignDefaultResourceColorsItem())) {
-        QColor defColor(0x37, 0x7A, 0xBC);
+    if (!color.isValid() && d->getBool(d->mBaseConfig.assignDefaultResourceColorsItem())) {
+        color.setRgb(0x37, 0x7A, 0xBC); // blueish
         const int seed = d->getInt(d->mBaseConfig.defaultResourceColorSeedItem());
         const QStringList colors = d->getStringList(d->mBaseConfig.defaultResourceColorsItem());
-        if (seed > 0 && seed - 1 < (int)colors.size()) {
-            defColor = QColor(colors[seed - 1]);
+        if (seed > 0 && seed - 1 < colors.size()) {
+            color.setNamedColor(colors[seed - 1]);
         } else {
-            createNewColor(defColor, seed);
+            color.setRgb(qrand() % 256, qrand() % 256, qrand() % 256);
         }
         d->setInt(d->mBaseConfig.defaultResourceColorSeedItem(), (seed + 1));
-        d->mBaseConfig.setResourceColor(cal, defColor);
-        color = d->mBaseConfig.mResourceColors[cal];
+        d->mBaseConfig.setResourceColor(cal, color);
     }
     if (color.isValid()) {
         return color;
